@@ -38,7 +38,7 @@ den_path ='/'.join(('resources', 'input.csv'))
 denPath = pkg_resources.resource_filename(resource_package, den_path)
 g_path = '/'.join(('resources', 'water_gibbs.csv'))
 gPath = pkg_resources.resource_filename(resource_package, g_path)
-sup_path = '/'.join(('resources', 'SUPCRTBL.exe'))
+sup_path = '/'.join(('resources', 'supcrt96.exe'))
 supPath =  pkg_resources.resource_filename(resource_package, sup_path)
 
 global Tr, bigQ, Chi, Pr, E_PrTr, bigR, Psi, Theta, Upsilon, Conversion, mineralDictionary
@@ -163,7 +163,7 @@ class DEW(object):
         '''A variable that stores the number of dielectric constant equation.'''
         self.psat = False
         '''A variable that stores the Psat option defined by input'''
-        self.myWatNumber = 1
+        self.waterDensity = 1
         '''A variable that stores the number of the density of water equation.'''
 
         
@@ -174,7 +174,7 @@ class DEW(object):
         '''The array of mineral inputs and multipliers defined by a user'''
         self.gasInputs = []
         '''The array of gas inputs and multipliers defined by a user'''
-        self.waterInp = []
+        self.waterInputs = []
         '''An array that defines if water is used in the input and hOw mUcH wAtEr?'''
         
         # Input Matrices
@@ -190,7 +190,7 @@ class DEW(object):
         '''The array of mineral outputs and multipliers defined by a user'''
         self.gasOutputs = []
         '''The array of gas outputs and multipliers defined by a user'''
-        self.waterOut = []
+        self.waterOutputs = []
         '''An array that defines if water is used in the outputand hOw mUcH wAtEr?'''
         
         # Output Matrices
@@ -243,23 +243,23 @@ class DEW(object):
         '''Used for debugging, stores the volume changes of aqueous outputs'''
         
         #Mineral Matrices
-        self.mineralsGInp = []
+        self.mineralInpGibbs = []
         '''Used for debugging, stores the free energy changes of mineral inputs'''
-        self.mineralsGOutput = []
+        self.mineralOutGibbs = []
         '''Used for debugging, stores the free energy changes of mineral outputs'''
-        self.mineralsVInp = [] 
+        self.mineralInpV = [] 
         '''Used for debugging, stores the volume changes of mineral inputs'''
-        self.mineralsVOutput = []
+        self.mineralOutV = []
         '''Used for debugging, stores the volume changes of mineral outputs'''
         
         #Water
-        self.InWaterG = []
+        self.waterInpGibbs = []
         '''Used for debugging, stores the free energy changes of water outputs'''
-        self.InWaterV = []
+        self.waterInpV = []
         '''Used for debugging, stores the volume changes of water inputs'''
-        self.OutWaterG = []
+        self.waterOutGibbs = []
         '''Used for debugging, stores the free energy changes of water outputs'''
-        self.OutWaterV = []
+        self.waterOutV = []
         '''Used for debugging, stores the volume changes of water outputs'''
         
         # Finals Arrays
@@ -405,7 +405,7 @@ class DEW(object):
                         print('Please enter a valid integer multiplier ')
             else: 
                 m3 = 0
-            self.waterInp.append([inpWater, m3])
+            self.waterInputs.append([inpWater, m3])
         return
     
     def set_outputs(self):
@@ -420,7 +420,7 @@ class DEW(object):
         self.mineralOutputs = []
         self.aqueousOutputs = []
         self.gasOutputs = []
-        self.waterOut = []
+        self.waterOutputs = []
 
 
         while mineralCount < 5:
@@ -516,7 +516,7 @@ class DEW(object):
                         print('Please enter a valid integer multiplier ')
             else: 
                 m3 = 0
-            self.waterOut.append([outWater, m3])
+            self.waterOutputs.append([outWater, m3])
         return
         
     
@@ -687,7 +687,7 @@ class DEW(object):
                     tempstep = int(input('Input the temperature step'))
                     pmin = int(input('Input the minimum pressure'))
                     pmax = int(input('Input the maximum pressure'))
-                    pstep = int(input('Input the pressure step'))
+                    pstep = input('Input the pressure step')
                     validBool = True
                 except ValueError:
                     print('You have entered a non-integer value, please start again')
@@ -894,19 +894,19 @@ class DEW(object):
         waterMatInV = []
         waterMatOutV = []
         if self.WaterFreeEq == 'D&H 1978':
-            self.myWatNumber = 1
-        elif self.WaterFreeEq == 'Integral of Volume':
-            self.myWatNumber = 2
+            self.waterDensity = 1
+        elif self.WaterFreeEq == 'Integral':
+            self.waterDensity = 2
         else:
-            self.myWatNumber = 3
+            self.waterDensity = 3
         
-        if self.waterInp[0][0] == 'yes':
+        if self.waterInputs[0][0] == 'yes':
             waterLst = []
             waterLst2 = []
             waterLst.append('H2O')
-            waterLst.append(self.waterInp[0][1])
+            waterLst.append(self.waterInputs[0][1])
             waterLst2.append('H2O')
-            waterLst2.append(self.waterInp[0][1])
+            waterLst2.append(self.waterInputs[0][1])
                                   
             for i in range(len(self.pressureUsed)):
             #for i in range(len(self.pressureUsed)):
@@ -919,7 +919,7 @@ class DEW(object):
                     except:
                         waterLst.append(GibbsH2O[i])
                 else:
-                    store = DEWEquations.DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.myWatNumber, self.equation, self.psat)
+                    store = DEWEquations.DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.waterDensity, self.equation, self.psat)
                     waterLst.append(store)
                 if self.DisplayVol == True:
                     try:
@@ -933,13 +933,13 @@ class DEW(object):
             waterMatInGibbs.append(waterLst)
             waterMatInV.append(waterLst2)
             
-        if self.waterOut[0][0] =='yes':
+        if self.waterOutputs[0][0] =='yes':
             waterLst = []
             waterLst2 = []
             waterLst.append('H2O')
-            waterLst.append(self.waterOut[0][1])
+            waterLst.append(self.waterOutputs[0][1])
             waterLst2.append('H2O')
-            waterLst2.append(self.waterOut[0][1])
+            waterLst2.append(self.waterOutputs[0][1])
             for i in range(len(self.pressureUsed)):
                 if self.WaterFreeEq == 'Custom':
                     try:
@@ -950,7 +950,7 @@ class DEW(object):
                     except:
                         waterLst.append(GibbsH2O[i])
                 else:
-                    waterLst.append(DEWEquations.DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.myWatNumber, self.equation, self.psat))
+                    waterLst.append(DEWEquations.DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.waterDensity, self.equation, self.psat))
                 if self.DisplayVol == True:
                     try:
                         waterLst2.append(18.01528/self.RhoWatArr[i])
@@ -1049,15 +1049,15 @@ class DEW(object):
         '''The function called that will update all of the parameters. It has no outputs, but allows certain arrays to be queried.
         '''
         self.calculate_matrices()
-        self.InWaterG, self.InWaterV, self.OutWaterG, self.OutWaterV = self.calculate_H2O()
+        self.waterInpGibbs, self.waterInpV, self.waterOutGibbs, self.waterOutV = self.calculate_H2O()
         self.aqInpGibbs, self.aqOutGibbs, self.aqInpV, self.aqOutV = self.calculate_aq()
         self.gasInpGibbs, self.gasOutGibbs, self.gasInpV, self.gasOutV = self.calculate_gas()
         
 
-        G1 = np.delete(np.asarray(self.InWaterG), [0,1]).astype(np.float) * int(self.waterInp[0][1])
-        V1 = np.delete(np.asarray(self.InWaterV), [0,1]).astype(np.float) * int(self.waterInp[0][1])
-        G4 = np.delete(np.asarray(self.OutWaterG), [0,1]).astype(np.float) * int(self.waterOut[0][1])
-        V4 = np.delete(np.asarray(self.OutWaterV), [0,1]).astype(np.float) * int(self.waterOut[0][1])
+        G1 = np.delete(np.asarray(self.waterInpGibbs), [0,1]).astype(np.float) * int(self.waterInputs[0][1])
+        V1 = np.delete(np.asarray(self.waterInpV), [0,1]).astype(np.float) * int(self.waterInputs[0][1])
+        G4 = np.delete(np.asarray(self.waterOutGibbs), [0,1]).astype(np.float) * int(self.waterOutputs[0][1])
+        V4 = np.delete(np.asarray(self.waterOutV), [0,1]).astype(np.float) * int(self.waterOutputs[0][1])
         
         # Gas Loops
         G3, V3 = ([], [])
@@ -1096,18 +1096,18 @@ class DEW(object):
         if len(self.mineralInputs) > 0:
             for i in range(len(self.mineralInputs)):
                 for temp in self.tempUsed:
-                    self.mineralsGInp.append(np.multiply(mineralDictionary[self.mineralInputs[i][0]]['delG'][mineralDictionary[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
-                    self.mineralsVInp.append(np.multiply(mineralDictionary[self.mineralInputs[i][0]]['delV'][mineralDictionary[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
-            dG = np.sum([dG, np.sum([self.mineralsGInp], axis = 0)], axis = 0)
-            dV = np.sum([dV, np.sum([self.mineralsVInp], axis = 0)], axis = 0)     
+                    self.mineralInpGibbs.append(np.multiply(mineralDictionary[self.mineralInputs[i][0]]['delG'][mineralDictionary[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
+                    self.mineralInpV.append(np.multiply(mineralDictionary[self.mineralInputs[i][0]]['delV'][mineralDictionary[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
+            dG = np.sum([dG, np.sum([self.mineralInpGibbs], axis = 0)], axis = 0)
+            dV = np.sum([dV, np.sum([self.mineralInpV], axis = 0)], axis = 0)     
             
         if len(self.mineralOutputs) > 0:
             for i in range(len(self.mineralOutputs)):
                 for temp in self.tempUsed:
-                    self.mineralsGOutput.append(np.multiply(mineralDictionary[self.mineralOutputs[i][0]]['delG'][mineralDictionary[self.mineralOutputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
-                    self.mineralsVOutput.append(np.multiply(mineralDictionary[self.mineralOutputs[i][0]]['delV'][mineralDictionary[self.mineralOutputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
-            dG = np.sum([dG, -np.sum([self.mineralsGOutput],axis = 0)], axis = 0)
-            dV = np.sum([dV, -np.sum([self.mineralsVOutput],axis = 0)], axis = 0)  
+                    self.mineralOutGibbs.append(np.multiply(mineralDictionary[self.mineralOutputs[i][0]]['delG'][mineralDictionary[self.mineralOutputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
+                    self.mineralOutV.append(np.multiply(mineralDictionary[self.mineralOutputs[i][0]]['delV'][mineralDictionary[self.mineralOutputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
+            dG = np.sum([dG, -np.sum([self.mineralOutGibbs],axis = 0)], axis = 0)
+            dV = np.sum([dV, -np.sum([self.mineralOutV],axis = 0)], axis = 0)  
             
         self.logK = []
         self.delG = []
@@ -1309,7 +1309,7 @@ class DEW(object):
         dG = [row[0] for row in self.delG]
         lK = [row[0] for row in self.logK]
         T = [row[1] for row in self.logK]
-        P = [row[1] for row in self.logK]
+        P = [row[2] for row in self.logK]
         output_array = np.column_stack([T,P, dV,dG,lK])
         df = pd.DataFrame(output_array)
         df.columns = ['Temperature','Pressure','delV','delG','LogK']
@@ -1337,8 +1337,11 @@ class DEW(object):
             running='\n' in line
         print('Finished')
     
-    def run_supcrt(self):
+    def run_supcrt(self, version = '96'):
         '''A function that runs the pre-compiled SUPCRTBL found in the file folder'''
+        if version != '96':
+            sup_path = '/'.join(('resources', 'SUPCRTBL.exe'))
+            supPath =  pkg_resources.resource_filename(resource_package, sup_path)
         self.proc = subprocess.Popen(supPath,shell = True, stdout = subprocess.PIPE, stdin = subprocess.PIPE, stderr = subprocess.STDOUT)
         self.pout = self.proc.stdout
         self.pin = self.proc.stdin
@@ -1352,6 +1355,129 @@ class DEW(object):
                 self.pin.write(inp)
                 self.pin.flush()
         return
+       
+    def calculate_supcrt_special(self, customFile = None):
+        '''Calculates the output from either SUPCRTBL/SUPCRT96 at isothermal/isobaric temperatures'''
+        returnLst = {}
+       
+        if customFile != None:
+            filename = op.dirname(op.abspath(__file__)) + '\\resources\\' + customFile
+        elif len(self.supcrtFile) ==0:
+            raise ValueError("You haven't run SUPCRT yet")
+        else:
+            filename = self.supcrtFile
+          
+        with open(filename, 'r') as f:
+            impor = f.read()
+            import_data = impor.replace('\t', ' ')
+
+        split = import_data.split('\n')
+        for i in range(len(split)):
+            try:
+                if 'ISOTHERMS(degC)' in split[i]:
+                    finalTemp = " ".join(split[i].split()).split(' ')[5]
+                    finalPress = " ".join(split[i+1].split()).split(' ')[6]
+                    returnVar = input('Enter reaction title')
+            except:
+                continue
+
+            if 'STANDARD STATE PROPERTIES OF THE REACTION AT ELEVATED TEMPERATURES AND PRESSURES' in split[i]:
+                subLst = []
+                temp = []
+                pres = []
+                DH2 = []
+                lgK = []
+                dlG = []
+                dlH = []
+                dlS = []
+                dlV = []
+                dlCp = []
+                subDict = {}
+                for item in split[(i+4):]:
+                    if len(item) > 0:
+                        subLst = (" ".join(item.split())).split(' ')
+                        try:
+                            float(subLst[0])
+                        except:
+                            continue
+                        try:
+                            a = subLst[0]
+                            b = subLst[1]
+                            c = subLst[2]
+                            d = subLst[3]
+                            e = subLst[4]
+                            f = subLst[5]
+                            g = subLst[6]
+                            h = subLst[7]
+                            i = subLst[8]
+                            temp.append(a)
+                            pres.append(b)
+                            DH2.append(c)
+                            lgK.append(d)
+                            dlG.append(e)
+                            dlH.append(f)
+                            dlS.append(g) 
+                            dlV.append(h)
+                            dlCp.append(i)
+                            if float(subLst[0]) == finalTemp and float(subLst[1]) == finalPress:
+                                break
+                        except:
+                            continue
+
+                subDict['Temperature'] = [float(i) for i in temp]
+                subDict['Pressure'] = [float(i) for i in pres]
+                DH2Lst = []
+                lgKLst = []
+                dlGLst = []
+                dlHLst = []
+                dlSLst = []
+                dlVLst = []
+                dlCpLst = []
+                for i in range(len(DH2)):
+                    try: 
+                        DH2Lst.append(float(DH2[i]))
+                    except:
+                        DH2Lst.append(0)
+
+                    try:
+                        lgKLst.append(float(lgK[i]))
+                    except: 
+                        lgKLst.append(0)
+
+                    try:
+                        dlGLst.append(float(dlG[i]))
+                    except:
+                        dlGLst.append(0)
+
+                    try:
+                        dlHLst.append(float(dlH[i]))
+                    except:
+                        dlHLst.append(0)
+
+                    try:
+                        dlSLst.append(float(dlS[i]))
+                    except:
+                        dlSLst.append(0)
+
+                    try:
+                        dlVLst.append(float(dlV[i]))
+                    except:
+                        dlVLst.append(0)
+
+                    try:
+                        dlCpLst.append(dlCp[i])
+                    except:
+                        dlCpLst.append[0]
+
+                subDict['DH2O'] = DH2Lst
+                subDict['LogK'] = lgKLst
+                subDict['delG'] = dlGLst
+                subDict['delH'] = dlHLst
+                subDict['delS'] = dlSLst
+                subDict['delV'] = dlVLst
+                subDict['delCp'] = dlCpLst
+                returnLst[returnVar] = subDict
+            self.supcrtOut = returnLst
     
     def calculate_supcrt(self, customFile = None):
         '''Calculates an output of thermodynamic properties from a SUPCRTBL output file in the same directory. User must input 
